@@ -2,8 +2,8 @@
  *
  * EVENTS.C - Timed event functions for Nagios
  *
- * Copyright (c) 1999-2009 Ethan Galstad (egalstad@nagios.org)
- * Last Modified: 06-16-2009
+ * Copyright (c) 1999-2010 Ethan Galstad (egalstad@nagios.org)
+ * Last Modified: 08-28-2010
  *
  * License:
  *
@@ -370,6 +370,7 @@ void init_timing_loop(void){
 			/* make sure the service can actually be scheduled when we want */
 			is_valid_time=check_time_against_period(temp_service->next_check,temp_service->check_period_ptr);
 			if(is_valid_time==ERROR){
+				log_debug_info(DEBUGL_EVENTS,2,"Preferred Time is Invalid In Timeperiod '%s': %lu --> %s",temp_service->check_period_ptr->name,(unsigned long)temp_service->next_check,ctime(&temp_service->next_check));
 				get_next_valid_time(temp_service->next_check,&next_valid_time,temp_service->check_period_ptr);
 				temp_service->next_check=next_valid_time;
 			        }
@@ -391,6 +392,10 @@ void init_timing_loop(void){
 	/* add scheduled service checks to event queue */
 	for(temp_service=service_list;temp_service!=NULL;temp_service=temp_service->next){
 
+		/* Nagios XI/NDOUtils MOD */
+		/* update status of all services (scheduled or not) */
+		update_service_status(temp_service,FALSE);
+
 		/* skip most services that shouldn't be scheduled */
 		if(temp_service->should_be_scheduled==FALSE){
 
@@ -522,6 +527,10 @@ void init_timing_loop(void){
 
 	/* add scheduled host checks to event queue */
 	for(temp_host=host_list;temp_host!=NULL;temp_host=temp_host->next){
+	
+		/* Nagios XI/NDOUtils Mod */
+		/* update status of all hosts (scheduled or not) */
+		update_host_status(temp_host,FALSE);
 
 		/* skip most hosts that shouldn't be scheduled */
 		if(temp_host->should_be_scheduled==FALSE){
@@ -1073,11 +1082,13 @@ int event_execution_loop(void){
 
 					run_event=FALSE;
 				        }
-
-			        }
+				}
 
 			/* run a few checks before executing a host check... */
-			if(event_list_low->event_type==EVENT_HOST_CHECK){
+			else if(event_list_low->event_type==EVENT_HOST_CHECK){
+
+				/* default action is to execute the event */
+				run_event=TRUE;
 
 				temp_host=(host *)event_list_low->event_data;
 
