@@ -2,8 +2,9 @@
  *
  * NOTIFICATIONS.C - Service and host notification functions for Nagios
  *
+ * Copyright (c) 2009-2010 Nagios Core Development Team and Community Contributors
  * Copyright (c) 1999-2008 Ethan Galstad (egalstad@nagios.org)
- * Last Modified: 10-15-2008
+ * Last Modified: 08-04-2010
  *
  * License:
  *
@@ -294,8 +295,10 @@ int service_notification(service *svc, int type, char *not_author, char *not_dat
 /* checks the viability of sending out a service alert (top level filters) */
 int check_service_notification_viability(service *svc, int type, int options){
 	host *temp_host;
+	timeperiod *temp_period;
 	time_t current_time;
 	time_t timeperiod_start;
+	time_t first_problem_time;
 	
 	log_debug_info(DEBUGL_FUNCTIONS,0,"check_service_notification_viability()\n");
 
@@ -324,8 +327,14 @@ int check_service_notification_viability(service *svc, int type, int options){
 		return ERROR;
 	        }
 
+	/* if the service has no notification period, inherit one from the host */
+	temp_period=svc->notification_period_ptr;
+	if(temp_period==NULL){
+		temp_period=svc->host_ptr->notification_period_ptr;
+		}
+
 	/* see if the service can have notifications sent out at this time */
-	if(check_time_against_period(current_time,svc->notification_period_ptr)==ERROR){
+	if(check_time_against_period(current_time,temp_period)==ERROR){
 
 		log_debug_info(DEBUGL_NOTIFICATIONS,1,"This service shouldn't have notifications sent out at this time.\n");
 
@@ -360,8 +369,14 @@ int check_service_notification_viability(service *svc, int type, int options){
 	/*********************************************/
 
 	/* custom notifications are good to go at this point... */
-	if(type==NOTIFICATION_CUSTOM)
+	if(type==NOTIFICATION_CUSTOM){
+		if(svc->scheduled_downtime_depth>0 || temp_host->scheduled_downtime_depth>0){
+			log_debug_info(DEBUGL_NOTIFICATIONS,1,"We shouldn't send custom notification during scheduled downtime.\n");
+			return ERROR;
+			}
 		return OK;
+		}
+
 
 
 	/****************************************/
@@ -411,7 +426,7 @@ int check_service_notification_viability(service *svc, int type, int options){
 	/****************************************/
 
 	/* downtime notifications only have to pass three general filters */
-	if(type==NOTIFICATION_DOWNTIMESTART || type==NOTIFICATION_DOWNTIMEEND || type==NOTIFICATION_DOWNTIMEEND){
+	if(type==NOTIFICATION_DOWNTIMESTART || type==NOTIFICATION_DOWNTIMEEND || type==NOTIFICATION_DOWNTIMECANCELLED){
 
 		/* don't send a notification if we're not supposed to... */
 		if(svc->notify_on_downtime==FALSE){
@@ -485,9 +500,21 @@ int check_service_notification_viability(service *svc, int type, int options){
 	/* see if enough time has elapsed for first notification (Mathias Sundman) */
 	/* 10/02/07 don't place restrictions on recoveries or non-normal notifications, must use last time ok (or program start) in calculation */
 	/* it is reasonable to assume that if the host was never up, the program start time should be used in this calculation */
-	if(type==NOTIFICATION_NORMAL && svc->current_notification_number==0 && svc->current_state!=STATE_OK && (current_time < (time_t)((svc->last_time_ok==(time_t)0L)?program_start:svc->last_time_ok + (svc->first_notification_delay*interval_length)))){
-		log_debug_info(DEBUGL_NOTIFICATIONS,1,"Not enough time has elapsed since the service changed to a non-OK state, so we should not notify about this problem yet\n");
-		return ERROR;
+	if(type==NOTIFICATION_NORMAL && svc->current_notification_number==0 && svc->current_state!=STATE_OK){
+
+		/* determine the time to use of the first problem point */
+		first_problem_time=svc->last_time_ok; /* not accurate, but its the earliest time we could use in the comparison */
+		if((svc->last_time_warning < first_problem_time) && (svc->last_time_warning > svc->last_time_ok))
+			first_problem_time=svc->last_time_warning;
+		if((svc->last_time_unknown < first_problem_time) && (svc->last_time_unknown > svc->last_time_ok))
+			first_problem_time=svc->last_time_unknown;
+		if((svc->last_time_critical < first_problem_time) && (svc->last_time_critical > svc->last_time_ok))
+			first_problem_time=svc->last_time_critical;
+	
+		if(current_time < (time_t)((first_problem_time==(time_t)0L)?program_start:first_problem_time + (svc->first_notification_delay*interval_length))){
+			log_debug_info(DEBUGL_NOTIFICATIONS,1,"Not enough time has elapsed since the service changed to a non-OK state, so we should not notify about this problem yet\n");
+			return ERROR;
+			}
 	        }
 
 	/* if this service is currently flapping, don't send the notification */
@@ -1184,6 +1211,7 @@ int host_notification(host *hst, int type, char *not_author, char *not_data, int
 int check_host_notification_viability(host *hst, int type, int options){
 	time_t current_time;
 	time_t timeperiod_start;
+	time_t first_problem_time;
 
 	log_debug_info(DEBUGL_FUNCTIONS,0,"check_host_notification_viability()\n");
 
@@ -1238,8 +1266,14 @@ int check_host_notification_viability(host *hst, int type, int options){
 	/*********************************************/
 
 	/* custom notifications are good to go at this point... */
-	if(type==NOTIFICATION_CUSTOM)
+	if(type==NOTIFICATION_CUSTOM){
+		if(hst->scheduled_downtime_depth>0){
+			log_debug_info(DEBUGL_NOTIFICATIONS,1,"We shouldn't send custom notification during scheduled downtime.\n");
+			return ERROR;
+			}
 		return OK;
+		}
+
 
 
 	/****************************************/
@@ -1355,9 +1389,19 @@ int check_host_notification_viability(host *hst, int type, int options){
 	/* see if enough time has elapsed for first notification (Mathias Sundman) */
 	/* 10/02/07 don't place restrictions on recoveries or non-normal notifications, must use last time up (or program start) in calculation */
 	/* it is reasonable to assume that if the host was never up, the program start time should be used in this calculation */
-	if(type==NOTIFICATION_NORMAL && hst->current_notification_number==0 && hst->current_state!=HOST_UP && (current_time < (time_t)((hst->last_time_up==(time_t)0L)?program_start:hst->last_time_up + (hst->first_notification_delay*interval_length)))){
-		log_debug_info(DEBUGL_NOTIFICATIONS,1,"Not enough time has elapsed since the host changed to a non-UP state (or since program start), so we shouldn't notify about this problem yet.\n");
-		return ERROR;
+	if(type==NOTIFICATION_NORMAL && hst->current_notification_number==0 && hst->current_state!=HOST_UP){
+
+		/* determine the time to use of the first problem point */
+		first_problem_time=hst->last_time_up; /* not accurate, but its the earliest time we could use in the comparison */
+		if((hst->last_time_down < first_problem_time) && (hst->last_time_down > hst->last_time_up))
+			first_problem_time=hst->last_time_down;
+		if((hst->last_time_unreachable < first_problem_time) && (hst->last_time_unreachable > hst->last_time_unreachable))
+			first_problem_time=hst->last_time_unreachable;
+	
+		if(current_time < (time_t)((first_problem_time==(time_t)0L)?program_start:first_problem_time + (hst->first_notification_delay*interval_length))){
+			log_debug_info(DEBUGL_NOTIFICATIONS,1,"Not enough time has elapsed since the host changed to a non-UP state (or since program start), so we shouldn't notify about this problem yet.\n");
+			return ERROR;
+			}
 	        }
 
 	/* if this host is currently flapping, don't send the notification */
