@@ -2,8 +2,8 @@
  *
  * SEHANDLERS.C - Service and host event and state handlers for Nagios
  *
- * Copyright (c) 1999-2009 Ethan Galstad (egalstad@nagios.org)
- * Last Modified:   01-02-2009
+ * Copyright (c) 1999-2010 Ethan Galstad (egalstad@nagios.org)
+ * Last Modified:   08-05-2010
  *
  * License:
  *
@@ -32,6 +32,9 @@
 #include "../include/perfdata.h"
 #include "../include/broker.h"
 
+#ifdef USE_EVENT_BROKER
+#include "../include/neberrors.h"
+#endif
 
 extern int             enable_event_handlers;
 extern int             obsess_over_services;
@@ -251,6 +254,7 @@ int run_global_service_event_handler(service *svc){
 #ifdef USE_EVENT_BROKER
 	struct timeval start_time;
 	struct timeval end_time;
+	int neb_result=OK;
 #endif
 	int macro_options=STRIP_ILLEGAL_MACRO_CHARS|ESCAPE_MACRO_CHARS;
 
@@ -275,13 +279,6 @@ int run_global_service_event_handler(service *svc){
 	gettimeofday(&start_time,NULL);
 #endif
 
-#ifdef USE_EVENT_BROKER
-	/* send event data to broker */
-	end_time.tv_sec=0L;
-	end_time.tv_usec=0L;
-	broker_event_handler(NEBTYPE_EVENTHANDLER_START,NEBFLAG_NONE,NEBATTR_NONE,GLOBAL_SERVICE_EVENTHANDLER,(void *)svc,svc->current_state,svc->state_type,start_time,end_time,exectime,event_handler_timeout,early_timeout,result,global_service_event_handler,NULL,NULL,NULL);
-#endif
-
 	/* get the raw command line */
 	get_raw_command_line(global_service_event_handler_ptr,global_service_event_handler,&raw_command,macro_options);
 	if(raw_command==NULL)
@@ -299,9 +296,25 @@ int run_global_service_event_handler(service *svc){
 	if(log_event_handlers==TRUE){
 		asprintf(&raw_logentry,"GLOBAL SERVICE EVENT HANDLER: %s;%s;$SERVICESTATE$;$SERVICESTATETYPE$;$SERVICEATTEMPT$;%s\n",svc->host_name,svc->description,global_service_event_handler);
 		process_macros(raw_logentry,&processed_logentry,macro_options);
-		logit(NSLOG_EVENT_HANDLER,FALSE,processed_logentry);
+		logit(NSLOG_EVENT_HANDLER,FALSE,"%s",processed_logentry);
 		}
 
+#ifdef USE_EVENT_BROKER
+	/* send event data to broker */
+	end_time.tv_sec=0L;
+	end_time.tv_usec=0L;
+	neb_result=broker_event_handler(NEBTYPE_EVENTHANDLER_START,NEBFLAG_NONE,NEBATTR_NONE,GLOBAL_SERVICE_EVENTHANDLER,(void *)svc,svc->current_state,svc->state_type,start_time,end_time,exectime,event_handler_timeout,early_timeout,result,global_service_event_handler,processed_command,NULL,NULL);
+
+	/* neb module wants to override (or cancel) the event handler - perhaps it will run the eventhandler itself */
+	if(neb_result==NEBERROR_CALLBACKOVERRIDE) {
+		my_free(processed_command);
+		my_free(raw_command);
+		my_free(raw_logentry);
+		my_free(processed_logentry);
+		return OK;
+	}
+#endif
+
 	/* run the command */
 	result=my_system(processed_command,event_handler_timeout,&early_timeout,&exectime,&command_output,0);
 
@@ -344,6 +357,7 @@ int run_service_event_handler(service *svc){
 #ifdef USE_EVENT_BROKER
 	struct timeval start_time;
 	struct timeval end_time;
+	int neb_result=OK;
 #endif
 	int macro_options=STRIP_ILLEGAL_MACRO_CHARS|ESCAPE_MACRO_CHARS;
 
@@ -364,12 +378,6 @@ int run_service_event_handler(service *svc){
 	gettimeofday(&start_time,NULL);
 #endif
 
-#ifdef USE_EVENT_BROKER
-	/* send event data to broker */
-	end_time.tv_sec=0L;
-	end_time.tv_usec=0L;
-	broker_event_handler(NEBTYPE_EVENTHANDLER_START,NEBFLAG_NONE,NEBATTR_NONE,SERVICE_EVENTHANDLER,(void *)svc,svc->current_state,svc->state_type,start_time,end_time,exectime,event_handler_timeout,early_timeout,result,svc->event_handler,NULL,NULL,NULL);
-#endif
 
 	/* get the raw command line */
 	get_raw_command_line(svc->event_handler_ptr,svc->event_handler,&raw_command,macro_options);
@@ -388,9 +396,25 @@ int run_service_event_handler(service *svc){
 	if(log_event_handlers==TRUE){
 		asprintf(&raw_logentry,"SERVICE EVENT HANDLER: %s;%s;$SERVICESTATE$;$SERVICESTATETYPE$;$SERVICEATTEMPT$;%s\n",svc->host_name,svc->description,svc->event_handler);
 		process_macros(raw_logentry,&processed_logentry,macro_options);
-		logit(NSLOG_EVENT_HANDLER,FALSE,processed_logentry);
+		logit(NSLOG_EVENT_HANDLER,FALSE,"%s",processed_logentry);
 		}
 
+#ifdef USE_EVENT_BROKER
+	/* send event data to broker */
+	end_time.tv_sec=0L;
+	end_time.tv_usec=0L;
+	neb_result=broker_event_handler(NEBTYPE_EVENTHANDLER_START,NEBFLAG_NONE,NEBATTR_NONE,SERVICE_EVENTHANDLER,(void *)svc,svc->current_state,svc->state_type,start_time,end_time,exectime,event_handler_timeout,early_timeout,result,svc->event_handler,processed_command,NULL,NULL);
+
+	/* neb module wants to override (or cancel) the event handler - perhaps it will run the eventhandler itself */
+	if(neb_result==NEBERROR_CALLBACKOVERRIDE) {
+		my_free(processed_command);
+		my_free(raw_command);
+		my_free(raw_logentry);
+		my_free(processed_logentry);
+		return OK;
+	}
+#endif
+
 	/* run the command */
 	result=my_system(processed_command,event_handler_timeout,&early_timeout,&exectime,&command_output,0);
 
@@ -476,6 +500,7 @@ int run_global_host_event_handler(host *hst){
 #ifdef USE_EVENT_BROKER
 	struct timeval start_time;
 	struct timeval end_time;
+	int neb_result=OK;
 #endif
 	int macro_options=STRIP_ILLEGAL_MACRO_CHARS|ESCAPE_MACRO_CHARS;
 
@@ -500,13 +525,6 @@ int run_global_host_event_handler(host *hst){
 	gettimeofday(&start_time,NULL);
 #endif
 
-#ifdef USE_EVENT_BROKER
-	/* send event data to broker */
-	end_time.tv_sec=0L;
-	end_time.tv_usec=0L;
-	broker_event_handler(NEBTYPE_EVENTHANDLER_START,NEBFLAG_NONE,NEBATTR_NONE,GLOBAL_HOST_EVENTHANDLER,(void *)hst,hst->current_state,hst->state_type,start_time,end_time,exectime,event_handler_timeout,early_timeout,result,global_host_event_handler,NULL,NULL,NULL);
-#endif
-
 	/* get the raw command line */
 	get_raw_command_line(global_host_event_handler_ptr,global_host_event_handler,&raw_command,macro_options);
 	if(raw_command==NULL)
@@ -524,9 +542,25 @@ int run_global_host_event_handler(host *hst){
 	if(log_event_handlers==TRUE){
 		asprintf(&raw_logentry,"GLOBAL HOST EVENT HANDLER: %s;$HOSTSTATE$;$HOSTSTATETYPE$;$HOSTATTEMPT$;%s\n",hst->name,global_host_event_handler);
 		process_macros(raw_logentry,&processed_logentry,macro_options);
-		logit(NSLOG_EVENT_HANDLER,FALSE,processed_logentry);
+		logit(NSLOG_EVENT_HANDLER,FALSE,"%s",processed_logentry);
 		}
 
+#ifdef USE_EVENT_BROKER
+	/* send event data to broker */
+	end_time.tv_sec=0L;
+	end_time.tv_usec=0L;
+	neb_result=broker_event_handler(NEBTYPE_EVENTHANDLER_START,NEBFLAG_NONE,NEBATTR_NONE,GLOBAL_HOST_EVENTHANDLER,(void *)hst,hst->current_state,hst->state_type,start_time,end_time,exectime,event_handler_timeout,early_timeout,result,global_host_event_handler,processed_command,NULL,NULL);
+
+	/* neb module wants to override (or cancel) the event handler - perhaps it will run the eventhandler itself */
+	if(neb_result==NEBERROR_CALLBACKOVERRIDE) {
+		my_free(processed_command);
+		my_free(raw_command);
+		my_free(raw_logentry);
+		my_free(processed_logentry);
+		return OK;
+	}
+#endif
+
 	/* run the command */
 	result=my_system(processed_command,event_handler_timeout,&early_timeout,&exectime,&command_output,0);
 
@@ -568,6 +602,7 @@ int run_host_event_handler(host *hst){
 #ifdef USE_EVENT_BROKER
 	struct timeval start_time;
 	struct timeval end_time;
+	int neb_result=OK;
 #endif
 	int macro_options=STRIP_ILLEGAL_MACRO_CHARS|ESCAPE_MACRO_CHARS;
 
@@ -588,13 +623,6 @@ int run_host_event_handler(host *hst){
 	gettimeofday(&start_time,NULL);
 #endif
 
-#ifdef USE_EVENT_BROKER
-	/* send event data to broker */
-	end_time.tv_sec=0L;
-	end_time.tv_usec=0L;
-	broker_event_handler(NEBTYPE_EVENTHANDLER_START,NEBFLAG_NONE,NEBATTR_NONE,HOST_EVENTHANDLER,(void *)hst,hst->current_state,hst->state_type,start_time,end_time,exectime,event_handler_timeout,early_timeout,result,hst->event_handler,NULL,NULL,NULL);
-#endif
-
 	/* get the raw command line */
 	get_raw_command_line(hst->event_handler_ptr,hst->event_handler,&raw_command,macro_options);
 	if(raw_command==NULL)
@@ -612,9 +640,25 @@ int run_host_event_handler(host *hst){
 	if(log_event_handlers==TRUE){
 		asprintf(&raw_logentry,"HOST EVENT HANDLER: %s;$HOSTSTATE$;$HOSTSTATETYPE$;$HOSTATTEMPT$;%s\n",hst->name,hst->event_handler);
 		process_macros(raw_logentry,&processed_logentry,macro_options);
-		logit(NSLOG_EVENT_HANDLER,FALSE,processed_logentry);
+		logit(NSLOG_EVENT_HANDLER,FALSE,"%s",processed_logentry);
 		}
 
+#ifdef USE_EVENT_BROKER
+	/* send event data to broker */
+	end_time.tv_sec=0L;
+	end_time.tv_usec=0L;
+	neb_result=broker_event_handler(NEBTYPE_EVENTHANDLER_START,NEBFLAG_NONE,NEBATTR_NONE,HOST_EVENTHANDLER,(void *)hst,hst->current_state,hst->state_type,start_time,end_time,exectime,event_handler_timeout,early_timeout,result,hst->event_handler,processed_command,NULL,NULL);
+
+	/* neb module wants to override (or cancel) the event handler - perhaps it will run the eventhandler itself */
+	if(neb_result==NEBERROR_CALLBACKOVERRIDE) {
+		my_free(processed_command);
+		my_free(raw_command);
+		my_free(raw_logentry);
+		my_free(processed_logentry);
+		return OK;
+	}
+#endif
+
 	/* run the command */
 	result=my_system(processed_command,event_handler_timeout,&early_timeout,&exectime,&command_output,0);
 
@@ -743,8 +787,9 @@ int handle_host_state(host *hst){
 			log_host_event(hst);
 
 		/* check for start of flexible (non-fixed) scheduled downtime */
-		if(hst->state_type==HARD_STATE)
-			check_pending_flex_host_downtime(hst);
+		/* CHANGED 08-05-2010 EG flex downtime can now start on soft states */
+		/*if(hst->state_type==HARD_STATE)*/
+		check_pending_flex_host_downtime(hst);
 
 		/* notify contacts about the recovery or problem if its a "hard" state */
 		if(hst->state_type==HARD_STATE)
@@ -779,5 +824,3 @@ int handle_host_state(host *hst){
 
 	return OK;
         }
-
-
