@@ -2,8 +2,8 @@
  *
  * HISTOGRAM.C -  Nagios Alert Histogram CGI
  *
- * Copyright (c) 2001-2008 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 01-08-2008
+ * Copyright (c) 2001-2008 Ethan Galstad (egalstad@nagios.org)
+ * Last Modified: 10-15-2008
  *
  * License:
  * 
@@ -358,7 +358,7 @@ int main(int argc, char **argv){
 				printf("<a href='%s?host=%s",AVAIL_CGI,url_encode(host_name));
 				printf("&service=%s&t1=%lu&t2=%lu&assumestateretention=%s&show_log_entries'>View Availability Report For This Service</a><BR>\n",url_encode(svc_description),t1,t2,(assume_state_retention==TRUE)?"yes":"no");
 				printf("<A HREF='%s?host=%s&",HISTORY_CGI,url_encode(host_name));
-				printf("service=%s'>View History This Service</A><BR>\n",url_encode(svc_description));
+				printf("service=%s'>View History For This Service</A><BR>\n",url_encode(svc_description));
 				printf("<A HREF='%s?host=%s&",NOTIFICATIONS_CGI,url_encode(host_name));
 				printf("service=%s'>View Notifications For This Service</A><BR>\n",url_encode(svc_description));
 		                }
@@ -407,9 +407,9 @@ int main(int argc, char **argv){
 			printf("<form method=\"GET\" action=\"%s\">\n",HISTOGRAM_CGI);
 			printf("<input type='hidden' name='t1' value='%lu'>\n",(unsigned long)t1);
 			printf("<input type='hidden' name='t2' value='%lu'>\n",(unsigned long)t2);
-			printf("<input type='hidden' name='host' value='%s'>\n",url_encode(host_name));
+			printf("<input type='hidden' name='host' value='%s'>\n",escape_string(host_name));
 			if(display_type==DISPLAY_SERVICE_HISTOGRAM)
-				printf("<input type='hidden' name='service' value='%s'>\n",url_encode(svc_description));
+				printf("<input type='hidden' name='service' value='%s'>\n",escape_string(svc_description));
 
 
 			printf("<tr><td CLASS='optBoxItem' valign=top align=left>Report period:</td><td CLASS='optBoxItem' valign=top align=left>Assume state retention:</td></tr>\n");
@@ -697,7 +697,7 @@ int main(int argc, char **argv){
 
 			for(temp_host=host_list;temp_host!=NULL;temp_host=temp_host->next){
 				if(is_authorized_for_host(temp_host,&current_authdata)==TRUE)
-					printf("<option value='%s'>%s\n",temp_host->name,temp_host->name);
+					printf("<option value='%s'>%s\n",escape_string(temp_host->name),temp_host->name);
 			        }
 
 			printf("</select>\n");
@@ -746,7 +746,7 @@ int main(int argc, char **argv){
 			printf("<TABLE BORDER=0 cellpadding=5>\n");
 			printf("<form method=\"GET\" action=\"%s\" name=\"serviceform\">\n",HISTOGRAM_CGI);
 			printf("<input type='hidden' name='input' value='getoptions'>\n");
-			printf("<input type='hidden' name='host' value='%s'>\n",(first_service==NULL)?"unknown":first_service);
+			printf("<input type='hidden' name='host' value='%s'>\n",(first_service==NULL)?"unknown":(char *)escape_string(first_service));
 
 			printf("<tr><td class='reportSelectSubTitle'>Service:</td>\n");
 			printf("<td class='reportSelectItem'>\n");
@@ -754,7 +754,7 @@ int main(int argc, char **argv){
 
 			for(temp_service=service_list;temp_service!=NULL;temp_service=temp_service->next){
 				if(is_authorized_for_service(temp_service,&current_authdata)==TRUE)
-					printf("<option value='%s'>%s;%s\n",temp_service->description,temp_service->host_name,temp_service->description);
+					printf("<option value='%s'>%s;%s\n",escape_string(temp_service->description),temp_service->host_name,temp_service->description);
 		                }
 
 			printf("</select>\n");
@@ -789,9 +789,9 @@ int main(int argc, char **argv){
 
 			printf("<TABLE BORDER=0 cellpadding=5>\n");
 			printf("<form method=\"GET\" action=\"%s\">\n",HISTOGRAM_CGI);
-			printf("<input type='hidden' name='host' value='%s'>\n",url_encode(host_name));
+			printf("<input type='hidden' name='host' value='%s'>\n",escape_string(host_name));
 			if(display_type==DISPLAY_SERVICE_HISTOGRAM)
-				printf("<input type='hidden' name='service' value='%s'>\n",url_encode(svc_description));
+				printf("<input type='hidden' name='service' value='%s'>\n",escape_string(svc_description));
 
 			printf("<tr><td class='reportSelectSubTitle' align=right>Report Period:</td>\n");
 			printf("<td class='reportSelectItem'>\n");
@@ -2338,6 +2338,7 @@ void convert_timeperiod_to_times(int type){
 	t->tm_sec=0;
 	t->tm_min=0;
 	t->tm_hour=0;
+        t->tm_isdst=-1;
 
 	switch(type){
 	case TIMEPERIOD_LAST24HOURS:
@@ -2426,6 +2427,7 @@ void compute_report_times(void){
 	st->tm_mday=start_day;
 	st->tm_mon=start_month-1;
 	st->tm_year=start_year-1900;
+	st->tm_isdst=-1;
 
 	t1=mktime(st);
 
@@ -2437,6 +2439,7 @@ void compute_report_times(void){
 	et->tm_mday=end_day;
 	et->tm_mon=end_month-1;
 	et->tm_year=end_year-1900;
+	et->tm_isdst=-1;
 
 	t2=mktime(et);
         }
