@@ -1363,6 +1363,7 @@ void convert_timeperiod_to_times(int type){
 	t->tm_sec=0;
 	t->tm_min=0;
 	t->tm_hour=0;
+        t->tm_isdst=-1;
 
 	switch(type){
 	case TIMEPERIOD_LAST24HOURS:
@@ -1453,6 +1454,7 @@ void compute_report_times(void){
 	st->tm_mday=start_day;
 	st->tm_mon=start_month-1;
 	st->tm_year=start_year-1900;
+	st->tm_isdst=-1;
 
 	t1=mktime(st);
 
@@ -1464,6 +1466,7 @@ void compute_report_times(void){
 	et->tm_mday=end_day;
 	et->tm_mon=end_month-1;
 	et->tm_year=end_year-1900;
+	et->tm_isdst=-1;
 
 	t2=mktime(et);
         }
