@@ -401,7 +401,7 @@ int main(int argc, char **argv){
 				printf("<a href='%s?host=%s",HISTOGRAM_CGI,url_encode(host_name));
 				printf("&service=%s&t1=%lu&t2=%lu&assumestateretention=%s'>View Alert Histogram For This Service</a><BR>\n",url_encode(svc_description),t1,t2,(assume_state_retention==TRUE)?"yes":"no");
 				printf("<A HREF='%s?host=%s&",HISTORY_CGI,url_encode(host_name));
-				printf("service=%s'>View Alert History This Service</A><BR>\n",url_encode(svc_description));
+				printf("service=%s'>View Alert History For This Service</A><BR>\n",url_encode(svc_description));
 				printf("<A HREF='%s?host=%s&",NOTIFICATIONS_CGI,url_encode(host_name));
 				printf("service=%s'>View Notifications For This Service</A><BR>\n",url_encode(svc_description));
 		                }
@@ -2818,6 +2818,7 @@ void convert_timeperiod_to_times(int type){
 	t->tm_sec=0;
 	t->tm_min=0;
 	t->tm_hour=0;
+        t->tm_isdst=-1;
 
 	switch(type){
 	case TIMEPERIOD_LAST24HOURS:
@@ -2905,6 +2906,7 @@ void compute_report_times(void){
 	st->tm_mday=start_day;
 	st->tm_mon=start_month-1;
 	st->tm_year=start_year-1900;
+	st->tm_isdst=-1;
 
 	t1=mktime(st);
 
@@ -2916,6 +2918,7 @@ void compute_report_times(void){
 	et->tm_mday=end_day;
 	et->tm_mon=end_month-1;
 	et->tm_year=end_year-1900;
+	et->tm_isdst=-1;
 
 	t2=mktime(et);
         }
