@@ -2,8 +2,8 @@
  *
  * MACROS.C - Common macro functions for Nagios
  *
- * Copyright (c) 1999-2009 Ethan Galstad (egalstad@nagios.org)
- * Last Modified: 06-23-2008
+ * Copyright (c) 1999-2010 Ethan Galstad (egalstad@nagios.org)
+ * Last Modified: 08-06-2010
  *
  * License:
  *
@@ -77,6 +77,7 @@ contactgroup    *macro_contactgroup_ptr=NULL;
 /* replace macros in notification commands with their values */
 int process_macros(char *input_buffer, char **output_buffer, int options){
 	char *temp_buffer=NULL;
+	char *save_buffer=NULL;
 	char *buf_ptr=NULL;
 	char *delim_ptr=NULL;
 	int in_macro=FALSE;
@@ -111,7 +112,9 @@ int process_macros(char *input_buffer, char **output_buffer, int options){
 	log_debug_info(DEBUGL_MACROS,1,"Processing: '%s'\n",input_buffer);
 #endif
 
-	buf_ptr=input_buffer;
+	/* use a duplicate of original buffer, so we don't modify the original */
+	save_buffer=buf_ptr=(input_buffer?strdup(input_buffer):NULL);
+
 	while(buf_ptr){
 
 		/* save pointer to this working part of buffer */
@@ -142,7 +145,7 @@ int process_macros(char *input_buffer, char **output_buffer, int options){
 			strcat(*output_buffer,temp_buffer);
 
 #ifdef NSCORE
-			log_debug_info(DEBUGL_MACROS,2,"  Not currently in macro.  Running output (%d): '%s'\n",strlen(*output_buffer),*output_buffer);
+			log_debug_info(DEBUGL_MACROS,2,"  Not currently in macro.  Running output (%zd): '%s'\n",strlen(*output_buffer),*output_buffer);
 #endif
 
 			in_macro=TRUE;
@@ -177,7 +180,7 @@ int process_macros(char *input_buffer, char **output_buffer, int options){
 			else if(!strcmp(temp_buffer,"")){
 
 #ifdef NSCORE
-				log_debug_info(DEBUGL_MACROS,2,"  Escaped $.  Running output (%d): '%s'\n",strlen(*output_buffer),*output_buffer);
+				log_debug_info(DEBUGL_MACROS,2,"  Escaped $.  Running output (%zd): '%s'\n",strlen(*output_buffer),*output_buffer);
 #endif
 
 				*output_buffer=(char *)realloc(*output_buffer,strlen(*output_buffer)+2);
@@ -188,7 +191,7 @@ int process_macros(char *input_buffer, char **output_buffer, int options){
 			else{
 
 #ifdef NSCORE
-				log_debug_info(DEBUGL_MACROS,2,"  Non-macro.  Running output (%d): '%s'\n",strlen(*output_buffer),*output_buffer);
+				log_debug_info(DEBUGL_MACROS,2,"  Non-macro.  Running output (%zd): '%s'\n",strlen(*output_buffer),*output_buffer);
 #endif
 
 				/* add the plain text to the end of the already processed buffer */
@@ -231,7 +234,7 @@ int process_macros(char *input_buffer, char **output_buffer, int options){
 						strcat(*output_buffer,cleaned_macro);
 
 #ifdef NSCORE
-						log_debug_info(DEBUGL_MACROS,2,"  Cleaned macro.  Running output (%d): '%s'\n",strlen(*output_buffer),*output_buffer);
+						log_debug_info(DEBUGL_MACROS,2,"  Cleaned macro.  Running output (%zd): '%s'\n",strlen(*output_buffer),*output_buffer);
 #endif
 						}
 					}
@@ -244,7 +247,7 @@ int process_macros(char *input_buffer, char **output_buffer, int options){
 						strcat(*output_buffer,selected_macro);
 
 #ifdef NSCORE
-						log_debug_info(DEBUGL_MACROS,2,"  Uncleaned macro.  Running output (%d): '%s'\n",strlen(*output_buffer),*output_buffer);
+						log_debug_info(DEBUGL_MACROS,2,"  Uncleaned macro.  Running output (%zd): '%s'\n",strlen(*output_buffer),*output_buffer);
 #endif
 						}
 					}
@@ -254,7 +257,7 @@ int process_macros(char *input_buffer, char **output_buffer, int options){
 					my_free(selected_macro);
 
 #ifdef NSCORE
-				log_debug_info(DEBUGL_MACROS,2,"  Just finished macro.  Running output (%d): '%s'\n",strlen(*output_buffer),*output_buffer);
+				log_debug_info(DEBUGL_MACROS,2,"  Just finished macro.  Running output (%zd): '%s'\n",strlen(*output_buffer),*output_buffer);
 #endif
 				}
 
@@ -262,6 +265,9 @@ int process_macros(char *input_buffer, char **output_buffer, int options){
 			}
 		}
 
+	/* free copy of input buffer */
+	my_free(save_buffer);
+
 #ifdef NSCORE
 	log_debug_info(DEBUGL_MACROS,1,"  Done.  Final output: '%s'\n",*output_buffer);
 	log_debug_info(DEBUGL_MACROS,1,"**** END MACRO PROCESSING *************\n");
@@ -615,8 +621,11 @@ int grab_macro_value(char *macro_buffer, char **output, int *clean_options, int
 		result=grab_custom_macro_value(macro_name,arg[0],arg[1],output);
 
 		/* custom variable values get cleaned */
+		/* CHANGED 09/01/10 EG as per discussion on -devel list.  Custom macros as user-defined, so they should be trusted and not cleaned */
+		/*
 		if(result==OK)
 			*clean_options|=(STRIP_ILLEGAL_MACRO_CHARS|ESCAPE_MACRO_CHARS);
+		*/
 		}
 
 	/* no macro matched... */
