@@ -10,7 +10,7 @@ include_once(dirname(__FILE__).'/includes/utils.inc.php');
 
 <HEAD>
 <META NAME="ROBOTS" CONTENT="NOINDEX, NOFOLLOW">
-<TITLE>Nagios</TITLE>
+<TITLE>Nagios Core</TITLE>
 <LINK REL='stylesheet' TYPE='text/css' HREF='stylesheets/common.css'>
 </HEAD>
 
@@ -25,9 +25,9 @@ include_once(dirname(__FILE__).'/includes/utils.inc.php');
 
 <div id="currentversioninfo">
 <div class="product">Nagios<sup><span style="font-size: small;">&reg;</span></sup> Core<sup><span style="font-size: small;">&trade;</span></sup></div>
-<div class="version">Version 3.2.1</div>
-<div class="releasedate">March 09, 2010</div>
-<div class="checkforupdates"><a href="http://www.nagios.org/checkforupdates/?version=3.2.1&product=nagioscore" target="_blank">Check for updates</a></div>
+<div class="version">Version 3.2.3</div>
+<div class="releasedate">October 03, 2010</div>
+<div class="checkforupdates"><a href="http://www.nagios.org/checkforupdates/?version=3.2.3&product=nagioscore" target="_blank">Check for updates</a></div>
 <div class="whatsnew"><a href="docs/whatsnew.html">Read what's new in Nagios Core 3</a></div>
 </div>
 
@@ -49,8 +49,8 @@ include_once(dirname(__FILE__).'/includes/utils.inc.php');
 	else if($updateinfo['update_available']==true){
 ?>
 		<div class="updateavailable">
-		<div class="updatemessage">A new version of Nagios is available!</div>
-		<div class="submessage">Visit <a href="http://www.nagios.org/" target="_blank">nagios.org</a> to download Nagios <?php echo $updateinfo['update_version'];?>.</div>
+		<div class="updatemessage">A new version of Nagios Core is available!</div>
+		<div class="submessage">Visit <a href="http://www.nagios.org/download/" target="_blank">nagios.org</a> to download Nagios <?php echo $updateinfo['update_version'];?>.</div>
 		</div>
 <?php
 		}
@@ -59,7 +59,7 @@ include_once(dirname(__FILE__).'/includes/utils.inc.php');
 
 
 <div id="mainfooter">
-<div id="maincopy">Copyright &copy; 2009 Nagios Core Development Team and Community Contributors.<br>Copyright &copy; 1999-2009 Ethan Galstad.<br>See the THANKS file for more information on contributors.</div>
+<div id="maincopy">Copyright &copy; 2010 Nagios Core Development Team and Community Contributors.<br>Copyright &copy; 1999-2009 Ethan Galstad.<br>See the THANKS file for more information on contributors.</div>
 <div CLASS="disclaimer">
 Nagios Core is licensed under the GNU General Public License and is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY, AND FITNESS FOR A PARTICULAR PURPOSE.  Nagios, Nagios Core and the Nagios logo are trademarks, servicemarks, registered trademarks or registered servicemarks owned by Nagios Enterprises, LLC.  Usage of the Nagios marks are governed by our <A href="http://www.nagios.org/legal/trademarkpolicy/">trademark policy</a>.
 </div>
