@@ -3,8 +3,8 @@
  * XRDDEFAULT.C - Default external state retention routines for Nagios
  *
  * Copyright (c) 2009 Nagios Core Development Team and Community Contributors
- * Copyright (c) 1999-2009 Ethan Galstad (egalstad@nagios.org)
- * Last Modified: 07-31-2009
+ * Copyright (c) 1999-2010 Ethan Galstad (egalstad@nagios.org)
+ * Last Modified: 09-01-2010
  *
  * License:
  *
@@ -75,6 +75,7 @@ extern int            use_retained_scheduling_info;
 extern int            retention_scheduling_horizon;
 
 extern time_t         last_update_check;
+extern unsigned long  update_uid;
 extern char           *last_program_version;
 extern int            update_available;
 extern char           *last_program_version;
@@ -324,6 +325,7 @@ int xrddefault_save_state_information(void){
 	fprintf(fp,"version=%s\n",PROGRAM_VERSION);
 	fprintf(fp,"last_update_check=%lu\n",last_update_check);
 	fprintf(fp,"update_available=%d\n",update_available);
+	fprintf(fp,"update_uid=%lu\n",update_uid);
 	fprintf(fp,"last_version=%s\n",(last_program_version==NULL)?"":last_program_version);
 	fprintf(fp,"new_version=%s\n",(new_program_version==NULL)?"":new_program_version);
 	fprintf(fp,"}\n");
@@ -359,6 +361,8 @@ int xrddefault_save_state_information(void){
 
 		fprintf(fp,"host {\n");
 		fprintf(fp,"host_name=%s\n",temp_host->name);
+		fprintf(fp,"alias=%s\n",temp_host->alias);
+		fprintf(fp,"display_name=%s\n",temp_host->display_name);
 		fprintf(fp,"modified_attributes=%lu\n",(temp_host->modified_attributes & ~host_attribute_mask));
 		fprintf(fp,"check_command=%s\n",(temp_host->host_check_command==NULL)?"":temp_host->host_check_command);
 		fprintf(fp,"check_period=%s\n",(temp_host->check_period==NULL)?"":temp_host->check_period);
@@ -429,6 +433,7 @@ int xrddefault_save_state_information(void){
 
 		fprintf(fp,"service {\n");
 		fprintf(fp,"host_name=%s\n",temp_service->host_name);
+		fprintf(fp,"display_name=%s\n",temp_service->display_name);
 		fprintf(fp,"service_description=%s\n",temp_service->description);
 		fprintf(fp,"modified_attributes=%lu\n",(temp_service->modified_attributes & ~service_attribute_mask));
 		fprintf(fp,"check_command=%s\n",(temp_service->service_check_command==NULL)?"":temp_service->service_check_command);
@@ -688,6 +693,10 @@ int xrddefault_read_state_information(void){
 	contact_host_attribute_mask=retained_contact_host_attribute_mask;
 	contact_service_attribute_mask=retained_contact_service_attribute_mask;
 
+	/* Big speedup when reading retention.dat in bulk */
+	defer_downtime_sorting=1;
+	defer_comment_sorting=1;
+
 	/* read all lines in the retention file */
 	while(1){
 
@@ -1034,6 +1043,8 @@ int xrddefault_read_state_information(void){
 					last_update_check=strtoul(val,NULL,10);
 				else if(!strcmp(var,"update_available"))
 					update_available=atoi(val);
+				else if(!strcmp(var,"update_uid"))
+					update_uid=strtoul(val,NULL,10);
 				else if(!strcmp(var,"last_version")){
 					if(last_program_version)
 						my_free(last_program_version);
@@ -1190,6 +1201,14 @@ int xrddefault_read_state_information(void){
 							temp_host->last_state=atoi(val);
 						else if(!strcmp(var,"last_hard_state"))
 							temp_host->last_hard_state=atoi(val);
+						else if(!strcmp(var,"alias")){
+							my_free(temp_host->alias);
+							temp_host->alias=(char *)strdup(val);
+							}
+						else if(!strcmp(var,"display_name")){
+							my_free(temp_host->display_name);
+							temp_host->display_name=(char *)strdup(val);
+							}
 						else if(!strcmp(var,"plugin_output")){
 							my_free(temp_host->plugin_output);
 							temp_host->plugin_output=(char *)strdup(val);
@@ -1461,6 +1480,10 @@ int xrddefault_read_state_information(void){
 							temp_service->last_state=atoi(val);
 						else if(!strcmp(var,"last_hard_state"))
 							temp_service->last_hard_state=atoi(val);
+						else if(!strcmp(var,"display_name")){
+							my_free(temp_service->display_name);
+							temp_service->display_name=(char *)strdup(val);
+							}
 						else if(!strcmp(var,"current_attempt"))
 							temp_service->current_attempt=atoi(val);
 						else if(!strcmp(var,"current_event_id"))
@@ -1861,6 +1884,11 @@ int xrddefault_read_state_information(void){
 	my_free(inputbuf);
 	mmap_fclose(thefile);
 
+	if(sort_downtime()!=OK)
+		return ERROR;
+	if(sort_comments()!=OK)
+		return ERROR;
+
 	if(test_scheduling==TRUE)
 		gettimeofday(&tv[1],NULL);
 
